@@ -63,15 +63,24 @@ class Run(Annotate):  # noqa: D101
                                           output files. [default: .]
             --antismash-sideload          write an AntiSMASH v6 sideload JSON
                                           file next to the output files.
+            --force-clusters-tsv          always write a ``clusters.tsv`` file
+                                          even when no clusters were found.
+
+        Parameters - Gene Calling:
+            -M, --mask                    Enable unknown region masking to
+                                          prevent genes from stretching across
+                                          unknown nucleotides.
 
         Parameters - Domain Annotation:
             -e <e>, --e-filter <e>        the e-value cutoff for protein domains
-                                          to be included.
+                                          to be included. This is not stable
+                                          across versions, so consider using
+                                          a p-value filter instead.
             -p <p>, --p-filter <p>        the p-value cutoff for protein domains
                                           to be included. [default: 1e-9]
 
         Parameters - Cluster Detection:
-            -c, --cds <N>                 the minimum number of coding sequences a
+            -c <N>, --cds <N>             the minimum number of coding sequences a
                                           valid cluster must contain. [default: 3]
             -m <m>, --threshold <m>       the probability threshold for cluster
                                           detection. Default depends on the
@@ -79,6 +88,13 @@ class Run(Annotate):  # noqa: D101
                                           0.6 for antismash).
             --postproc <method>           the method to use for cluster validation
                                           (antismash or gecco). [default: gecco]
+            -E <N>, --edge-distance <N>   the minimum number of annotated genes
+                                          that must separate a cluster from the
+                                          edge. Edge clusters will still be
+                                          included if they are longer. A lower
+                                          number will increase the number of
+                                          false positives on small contigs.
+                                          [default: 10]
 
         Parameters - Debug:
             --model <directory>           the path to an alternative CRF model
@@ -111,12 +127,15 @@ class Run(Annotate):  # noqa: D101
                 self.threshold = self._check_flag("--threshold", float, lambda x: 0 <= x <= 1, hint="number between 0 and 1")
             self.jobs = self._check_flag("--jobs", int, lambda x: x >= 0, hint="positive or null integer")
             self.postproc = self._check_flag("--postproc", str, lambda x: x in ("gecco", "antismash"), hint="'gecco' or 'antismash'")
+            self.edge_distance = self._check_flag("--edge-distance", int, lambda x: x >= 0, hint="positive or null integer")
             self.format = self._check_flag("--format")
             self.genome = self._check_flag("--genome")
             self.model = self._check_flag("--model")
             self.hmm = self._check_flag("--hmm")
             self.output_dir = self._check_flag("--output-dir")
             self.antismash_sideload = self._check_flag("--antismash-sideload", bool)
+            self.force_clusters_tsv = self._check_flag("--force-clusters-tsv", bool)
+            self.mask = self._check_flag("--mask", bool)
         except InvalidArgument:
             raise CommandExit(1)
 
@@ -170,7 +189,7 @@ class Run(Annotate):  # noqa: D101
 
         self.info("Predicting", "cluster probabilitites with the CRF model", level=1)
         unit = "genes" if len(genes) > 1 else "gene"
-        task = self.progress.add_task("Prediction", total=len(genes), unit=unit, precision="")
+        task = self.progress.add_task("Predicting marginals", total=len(genes), unit=unit, precision="")
         return list(crf.predict_probabilities(
             self.progress.track(genes, task_id=task, total=len(genes)),
             cpus=self.jobs
@@ -189,11 +208,16 @@ class Run(Annotate):  # noqa: D101
         from ...refine import ClusterRefiner
 
         self.info("Extracting", "predicted biosynthetic regions", level=1)
-        refiner = ClusterRefiner(self.threshold, self.postproc, self.cds)
+        refiner = ClusterRefiner(
+            threshold=self.threshold,
+            criterion=self.postproc,
+            n_cds=self.cds,
+            edge_distance=self.edge_distance
+        )
 
         total = len({gene.source.id for gene in genes})
         unit = "contigs" if total > 1 else "contig"
-        task = self.progress.add_task("Segmentation", total=total, unit=unit, precision="")
+        task = self.progress.add_task("Extracting clusters", total=total, unit=unit, precision="")
 
         clusters = []
         gene_groups = itertools.groupby(genes, lambda g: g.source.id)
@@ -209,7 +233,7 @@ class Run(Annotate):  # noqa: D101
         self.info("Predicting", "BGC types", level=1)
 
         unit = "cluster" if len(clusters) == 1 else "clusters"
-        task = self.progress.add_task("Type prediction", total=len(clusters), unit=unit, precision="")
+        task = self.progress.add_task("Predicting types", total=len(clusters), unit=unit, precision="")
 
         clusters_new = []
         classifier = TypeClassifier.trained(self.model)
@@ -324,6 +348,8 @@ class Run(Annotate):  # noqa: D101
                 self.success("Found", len(clusters), "potential gene clusters", level=1)
             else:
                 self.warn("No gene clusters were found")
+                if self.force_clusters_tsv:
+                    self._write_cluster_table(clusters)
                 return 0
             # predict types for putative clusters
             clusters = self._predict_types(clusters)
